"""
Function parameter counts for validation in STEAM_materials_ULTRA.

This file is auto-generated from all_material_functions.csv.
DO NOT EDIT MANUALLY - regenerate using utils/update_function_parameters.py
"""

FUNCTION_PARAMS = {
    "CFUN_CpHeMass_v1": 1,
    "CFUN_CvAg_v1": 1,
    "CFUN_CvAl5083_v1": 1,
    "CFUN_CvAlAlloy_v1": 1,
    "CFUN_CvAl_v1": 1,
    "CFUN_CvBSCCO2212_v1": 1,
    "CFUN_CvBeCu_v1": 1,
    "CFUN_CvBrass_v1": 1,
    "CFUN_CvCu_CUDI_v1": 1,
    "CFUN_CvCu_NIST_v1": 1,
    "CFUN_CvCu_v1": 1,
    "CFUN_CvG10_v1": 1,
    "CFUN_CvHast_v1": 1,
    "CFUN_CvHeMass_v1": 1,
    "CFUN_CvHe_CUDI_v1": 1,
    "CFUN_CvHe_NIST_v1": 1,
    "CFUN_CvHe_v1": 1,
    "CFUN_CvIn_v0": 1,
    "CFUN_CvKapton_v1": 1,
    "CFUN_CvNb3Sn_Arp_Knapp_v1": 4,
    "CFUN_CvNb3Sn_Arp_Knapp_v2": 4,
    "CFUN_CvNb3Sn_v1": 2,
    "CFUN_CvNb3Sn_v2": 4,
    "CFUN_CvNbTi_CUDI_v1": 2,
    "CFUN_CvNbTi_v1": 5,
    "CFUN_CvSS316_NIST_v1": 1,
    "CFUN_CvSteel_v1": 1,
    "CFUN_CvTi_v1": 1,
    "CFUN_HTS_JcFit_Benchmark_v1": 1,
    "CFUN_HTS_JcFit_Fujikura_v1": 3,
    "CFUN_HTS_JcFit_SUPERPOWER_v1": 3,
    "CFUN_HTS_JcFit_Succi_v2": 2,
    "CFUN_HTS_JcFit_THEVA_v1": 3,
    "CFUN_HTS_JcFit_sunam_v1": 3,
    "CFUN_IcNb3Sn_HiLumi_v1": 3,
    "CFUN_IcNb3Sn_WithStress_v1": 6,
    "CFUN_IcNb3Sn_v1": 3,
    "CFUN_IcNbTi_v1": 3,
    "CFUN_JcNbTiLowCurrent_v1": 2,
    "CFUN_Jc_Nb3Sn_Bordini_v1": 6,
    "CFUN_Jc_Nb3Sn_Bottura_v1": 9,
    "CFUN_Jc_Nb3Sn_HFM_v1": 9,
    "CFUN_Jc_Nb3Sn_Summers_v1": 5,
    "CFUN_Jc_NbTi_Bottura_v1": 11,
    "CFUN_Jc_NbTi_Cudi_fit1_v1": 8,
    "CFUN_Jc_NbTi_Cudi_v1": 12,
    "CFUN_Jc_T_B_BSCCO2212_Power_Gosh_v1": 3,
    "CFUN_Jc_T_B_BSCCO2212_Power_Jiang_Wesche_v1": 3,
    "CFUN_Jc_T_B_BSCCO2212_new_v1": 3,
    "CFUN_Jc_T_B_BSCCO2212_v1": 3,
    "CFUN_NZPV_v1": 5,
    "CFUN_P2vsT2_cryocooler_SHI_SRDE_418D4_v2": 1,
    "CFUN_PvsT_cryocooler_SHI_SRDE_418D4_v1": 1,
    "CFUN_QHCircuitRLC_v1": 11,
    "CFUN_QHCircuit_v1": 10,
    "CFUN_QHCircuit_v2": 10,
    "CFUN_QHCircuit_v3": 11,
    "CFUN_TcNb3Sn_v1": 3,
    "CFUN_TcNbTi_v1": 3,
    "CFUN_TcsNbTi_v1": 4,
    "CFUN_Tcs_Nb3Sn_v1": 6,
    "CFUN_densityHe_v1": 1,
    "CFUN_fisc_I_Ic_n_rhom_Am_BSCCO2212_v1": 5,
    "CFUN_hHe_v1": 2,
    "CFUN_hN_v1": 1,
    "CFUN_kAg_RRR30_v1": 1,
    "CFUN_kAg_v1": 1,
    "CFUN_kAl1350_v1": 1,
    "CFUN_kAl5083_v1": 1,
    "CFUN_kAl6061_v1": 1,
    "CFUN_kAlAlloy_v1": 2,
    "CFUN_kBeCu_WiedemannFranz_v1": 3,
    "CFUN_kBrass_v1": 1,
    "CFUN_kCu_Wiedemann_v1": 2,
    "CFUN_kCu_v1": 4,
    "CFUN_kG10_v1": 1,
    "CFUN_kG10_v2": 1,
    "CFUN_kHast_v1": 1,
    "CFUN_kHe_v1": 2,
    "CFUN_kIn_v0": 1,
    "CFUN_kKapton_v1": 1,
    "CFUN_kKapton_v2": 1,
    "CFUN_kSteel_v1": 1,
    "CFUN_kSteel_v2": 1,
    "CFUN_kStycast_v1": 1,
    "CFUN_n_T_B_BSCCO2212_Jiang_Wesche_v1": 3,
    "CFUN_quenchState_v1": 2,
    "CFUN_rhoAgMg_v1": 2,
    "CFUN_rhoAg_v1": 4,
    "CFUN_rhoAl1350_v1": 1,
    "CFUN_rhoAl5083_v1": 1,
    "CFUN_rhoAl6061_v1": 1,
    "CFUN_rhoAlAlloy_v1": 2,
    "CFUN_rhoAl_v1": 1,
    "CFUN_rhoAl_v2": 1,
    "CFUN_rhoBeCu_v1": 2,
    "CFUN_rhoCu_CUDI_v1": 4,
    "CFUN_rhoCu_NIST_v1": 3,
    "CFUN_rhoCu_NIST_v2": 3,
    "CFUN_rhoCu_v1": 4,
    "CFUN_rhoHast_v1": 1,
    "CFUN_rhoHast_v2": 1,
    "CFUN_rhoIn_v0": 1,
    "CFUN_rhoSS_v1": 1,
}
